@@ -9,7 +9,7 @@
 #   Purpose : python library module to copy, move and delete data files locally
 #             and remotely
 #
-#    Github : https://github.com/NCAR/rda-python_common.git
+#    Github : https://github.com/NCAR/rda-python-common.git
 #
 ###############################################################################
 #
@@ -67,7 +67,7 @@ OHOST = PgLOG.PGLOG['OBJCTSTR']
 BHOST = PgLOG.PGLOG['BACKUPNM']
 DHOST = PgLOG.PGLOG['DRDATANM']
 OBJCTCMD = "isd_s3_cli"
-BACKCMD = "dsglobus" 
+BACKCMD = "dsglobus"
 
 HLIMIT = 0    # HTAR file count limit
 BLIMIT = 2    # minimum back tar file size in DB 
@@ -101,23 +101,25 @@ QSTATS = {
 }
 
 QPOINTS = {
-   'L' : 'rda-glade',
-   'B' : 'rda-quasar',
-   'D' : 'rda-quasar-drdata'
+   'L' : 'gdex-glade',
+   'B' : 'gdex-quasar',
+   'D' : 'gdex-quasar-drdata'
 }
 
 QHOSTS = {
-   'rda-glade' : LHOST,
-   'rda-quasar' : BHOST,
-   'rda-quasar-drdata' : DHOST
+   'gdex-glade' : LHOST,
+   'gdex-quasar' : BHOST,
+   'gdex-quasar-drdata' : DHOST
 }
 
 ENDPOINTS = {
-   'rda-glade' : "NCAR RDA GLADE",
-   'rda-quasar' : "NCAR RDA Quasar",
-   'rda-quasar-drdata' : "NCAR RDA Quasar DRDATA"
+   'gdex-glade' : "NCAR RDA GLADE",
+   'gdex-quasar' : "NCAR RDA Quasar",
+   'gdex-quasar-drdata' : "NCAR RDA Quasar DRDATA"
 }
 
+BFILES = {}  # cache backup file names and dates for each bid
+
 #
 # reset the up limit for a specified error type
 #
@@ -143,7 +145,7 @@ def errlog(msg, etype, retry = 0, logact = 0):
           logact |= PgLOG.EXITLG
           ECNTS[etype] = 0
 
-   if PgLOG.PGLOG['DSCHECK'] and logact&PgLOG.EXITLG: PgDBI.record_dscheck_error(msg)
+   if PgLOG.PGLOG['DSCHECK'] and logact&PgLOG.EXITLG: PgDBI.record_dscheck_error(msg, logact)
    PgLOG.pglog(msg, logact)
    PgLOG.PGLOG['BCKGRND'] = bckgrnd
    if not retry: time.sleep(PgSIG.PGSIG['ETIME'])
@@ -330,23 +332,34 @@ def local_copy_object(tofile, fromfile, bucket = None, meta = None, logact = 0):
 #   tofiles - target file name list, echo name leading with /dsnnn.n/ on Quasar and 
 #             leading with /data/ or /decsdata/ on local glade disk
 # fromfiles - source file name list, the same format as the tofiles
-#   topoint - target endpoint name, 'rda-glade', 'rda-quasar' or 'rda-quasar-drdata' 
+#   topoint - target endpoint name, 'gdex-glade', 'gdex-quasar' or 'gdex-quasar-drdata' 
 # frompoint - source endpoint name, the same choices as the topoint
 #
 def quasar_multiple_trasnfer(tofiles, fromfiles, topoint, frompoint, logact = 0):
 
    ret = PgLOG.FAILURE
-   qstr = '{"action":"transfer","label":"%s","verify_checksum":true,' % ENDPOINTS[topoint]
-#   qstr = '{"action":"transfer","label":"%s",' % ENDPOINTS[topoint]
-   qstr += '"source_endpoint":"%s","destination_endpoint":"%s","files":[\n' % (frompoint, topoint)
-   fcnt = len(fromfiles)
-   bstr = ''
-   for i in range(fcnt):
-      qstr += '%s{"source_file":"%s","destination_file":"%s"}' % (bstr, fromfiles[i], tofiles[i])
-      if i == 0: bstr = ',\n'
-   qstr += ']}'
 
-   task = submit_globus_task(BACKCMD, topoint, logact, qstr)
+   fcnt = len(fromfiles)
+   transfer_files = {"files": []}
+   for i in range(fcnt):
+      transfer_files["files"].append({
+         "source_file": fromfiles[i],
+         "destination_file": tofiles[i]
+      })
+   qstr = json.dumps(transfer_files)
+
+   action = 'transfer'
+   source_endpoint = frompoint
+   destination_endpoint = topoint
+   label = f"{ENDPOINTS[frompoint]} to {ENDPOINTS[topoint]} {action}"
+   verify_checksum = True
+
+   cmd = f'{BACKCMD} {action} -se {source_endpoint} -de {destination_endpoint} --label "{label}"'
+   if verify_checksum:
+      cmd += ' -vc'   
+   cmd += ' --batch -'
+
+   task = submit_globus_task(cmd, topoint, logact, qstr)
    if task['stat'] == 'S':
       ret = PgLOG.SUCCESS
    elif task['stat'] == 'A':
@@ -361,7 +374,7 @@ def quasar_multiple_trasnfer(tofiles, fromfiles, topoint, frompoint, logact = 0)
 #    tofile - target file name, leading with /dsnnn.n/ on Quasar and 
 #             leading with /data/ or /decsdata/ on local glade disk
 #  fromfile - source file, the same format as the tofile
-#   topoint - target endpoint name, 'rda-glade', 'rda-quasar' or 'rda-quasar-drdata' 
+#   topoint - target endpoint name, 'gdex-glade', 'gdex-quasar' or 'gdex-quasar-drdata' 
 # frompoint - source endpoint name, the same choices as the topoint
 #
 def endpoint_copy_endpoint(tofile, fromfile, topoint, frompoint, logact = 0):
@@ -377,7 +390,9 @@ def endpoint_copy_endpoint(tofile, fromfile, topoint, frompoint, logact = 0):
       if tinfo and tinfo['data_size'] > 0:
          return PgLOG.pglog("{}-{}: file exists already".format(topoint, tofile), logact)
 
-   cmd = "{} -t -vc -se {} -de {} -sf {} -df {}".format(BACKCMD, frompoint, topoint, fromfile, tofile)
+   action = 'transfer'
+   cmd = f'{BACKCMD} {action} -se {frompoint} -de {topoint} -sf {fromfile} -df {tofile} -vc'
+
    task = submit_globus_task(cmd, topoint, logact)
    if task['stat'] == 'S':
       ret = PgLOG.SUCCESS
@@ -433,7 +448,8 @@ def check_globus_status(taskid, endpoint = None, logact = 0):
    if not taskid: return ret
    if not endpoint: endpoint = PgLOG.PGLOG['BACKUPEP']
    mp = r'Status:\s+({})'.format('|'.join(QSTATS.values()))
-   cmd = "{} -gt --task-id {}".format(BACKCMD, taskid)
+
+   cmd = f"{BACKCMD} get-task {taskid}"
    astats = ['OK', 'Queued']
 
    for loop in range(2):
@@ -450,7 +466,7 @@ def check_globus_status(taskid, endpoint = None, logact = 0):
                      if logact&PgLOG.NOWAIT:
                         errmsg = "{}: Cancel Task due to {}:\n{}".format(taskid, detail, buf)
                         errlog(errmsg, 'B', 1, logact)
-                        ccmd = "{} -ct --task-id {}".format(BACKCMD, taskid)
+                        ccmd = f"{BACKCMD} cancel-task {taskid}"
                         PgLOG.pgsystem(ccmd, logact, 7)
                      else:
                         time.sleep(PgSIG.PGSIG['ETIME'])
@@ -516,7 +532,7 @@ def check_globus_finished(tofile, topoint, logact = 0):
 def local_copy_backup(tofile, fromfile, endpoint = None, logact = 0):
 
    if not endpoint: endpoint = PgLOG.PGLOG['BACKUPEP']
-   return endpoint_copy_endpoint(tofile, fromfile, endpoint, 'rda-glade', logact)
+   return endpoint_copy_endpoint(tofile, fromfile, endpoint, 'gdex-glade', logact)
 
 #
 # Copy a  Quasar backup file to local Globus endpoint
@@ -528,7 +544,7 @@ def local_copy_backup(tofile, fromfile, endpoint = None, logact = 0):
 def backup_copy_local(tofile, fromfile, endpoint = None, logact = 0):
 
    if not endpoint: endpoint = PgLOG.PGLOG['BACKUPEP']
-   return endpoint_copy_endpoint(tofile, fromfile, 'rda-glade', endpoint, logact)
+   return endpoint_copy_endpoint(tofile, fromfile, 'gdex-glade', endpoint, logact)
 
 #
 # Copy a remote file to local
@@ -757,7 +773,7 @@ def delete_backup_file(file, endpoint = None, logact = 0):
    info = check_backup_file(file, endpoint, 0, logact)
    if not info: return PgLOG.FAILURE
 
-   cmd = "{} -d -ep {} -tf {}".format(BACKCMD, endpoint, file)
+   cmd = f"{BACKCMD} delete -ep {endpoint} -tf {file}"
    task = submit_globus_task(cmd, endpoint, logact)
    if task['stat'] == 'S':
       return PgLOG.SUCCESS
@@ -1026,7 +1042,7 @@ def move_backup_file(tofile, fromfile, endpoint = None, logact = 0):
    elif tinfo != None:
       return ret
 
-   cmd = "{} --rename -ep {} --oldpath {} --newpath {}".format(BACKCMD, endpoint, fromfile, tofile)
+   cmd = f"{BACKCMD} rename -ep {endpoint} --old-path {fromfile} --new-path {tofile}"
    loop = 0
    while loop < 2:
       buf = PgLOG.pgsystem(cmd, logact, CMDRET)
@@ -1123,7 +1139,8 @@ def make_one_remote_directory(dir, odir, host, logact = 0):
    if is_root_directory(dir, 'R', host, "make directory {} on {}".format(odir, host), logact): return PgLOG.FAILURE
  
    if make_one_remote_directory(op.dirname(dir), odir, host, logact):
-      if PgLOG.pgsystem("{} {} {}".format(PgLOG.get_sync_command(host), PgLOG.PGLOG['TMPSYNC'], dir), logact, 5):
+      tmpsync = PgLOG.get_tmpsync_path()
+      if PgLOG.pgsystem("{} {} {}".format(PgLOG.get_sync_command(host), tmpsync, dir), logact, 5):
          set_remote_mode(dir, 0, host, PgLOG.PGLOG['EXECMODE'])
          return PgLOG.SUCCESS
    
@@ -1155,7 +1172,7 @@ def make_one_backup_directory(dir, odir, endpoint = None, logact = 0):
    if not odir: odir = dir
    if not make_one_backup_directory(op.dirname(dir), odir, endpoint, logact): return PgLOG.FAILURE
 
-   cmd = "{} --mkdir -ep {} -p {}".format(BACKCMD, endpoint, dir)
+   cmd = f"{BACKCMD} mkdir -ep {endpoint} -p {dir}"
    for loop in range(2):
       buf = PgLOG.pgsystem(cmd, logact, CMDRET)
       syserr = PgLOG.PGLOG['SYSERR']
@@ -1467,7 +1484,7 @@ def local_host_action(host, action, info, logact = 0):
    if host == "partition":
       msg = "for individual partition"
    elif host == "rda_config":
-      msg = "via https://rda.ucar.edu/internal/rda_pg_config"
+      msg = "via https://gdex.ucar.edu/internal/rda_pg_config"
    elif host in PgLOG.BCHCMDS:
       msg = "on a {} Node".format(host)
    else:
@@ -1560,7 +1577,7 @@ def check_rda_file(file, host = LHOST, opt = 0, logact = 0):
 def check_globus_file(file, endpoint = None, opt = 0, logact = 0):
 
    if not endpoint: endpoint = PgLOG.PGLOG['BACKUPEP']
-   if endpoint == 'rda-glade':
+   if endpoint == 'gdex-glade':
       if re.match(r'^/(data|decsdata)/', file): file = PgLOG.PGLOG['DSSDATA'] + file
       return check_local_file(file, opt, logact)
    else:
@@ -1840,7 +1857,7 @@ def check_backup_file(file, endpoint = None, opt = 0, logact = 0):
    if not endpoint: endpoint = PgLOG.PGLOG['BACKUPEP']
    bdir = op.dirname(file)
    bfile = op.basename(file)
-   cmd = "{} -ls -ep {} -p {} --filter {}".format(BACKCMD, endpoint, bdir, bfile)
+   cmd = f"{BACKCMD} ls -ep {endpoint} -p {bdir} --filter {bfile}"
    ccnt = loop = 0
    while loop < 2:
       buf = PgLOG.pgsystem(cmd, logact, CMDRET)
@@ -2205,7 +2222,8 @@ def backup_glob(dir, endpoint = None, opt = 0, logact = 0):
 
    if not dir: return None
    if not endpoint: endpoint = PgLOG.PGLOG['BACKUPEP']
-   cmd = "{} -ls -ep {} -p {}".format(BACKCMD, endpoint, dir)
+
+   cmd = f"{BACKCMD} ls -ep {endpoint} -p {dir}"
    flist = {}
    for loop in range(2):
       buf = PgLOG.pgsystem(cmd, logact, CMDRET)
@@ -3012,3 +3030,52 @@ def check_storage_dflags(dflags, dscheck = None, logact = 0):
       if cidx: PgDBI.pgexec("UPDATE dscheck SET dflags = '' WHERE cindex = {}".format(cidx), logact)
 
    return msgary
+
+#
+# check a RDA file is backed up or not for given file record;
+# clear the cached bfile records if frec is None.
+# return 0 if not yet, 1 if backed up, or -1 if backed up but modified
+#
+def file_backup_status(frec, chgdays = 1, logact = 0):
+
+   if frec is None:
+      BFILES.clear()
+      return 0
+
+   bid = frec['bid']
+   if not bid: return 0
+
+   fields = 'bfile, dsid, date_modified'
+   if chgdays > 0: fields += ', note'
+   if bid not in BFILES: BFILES[bid] = PgDBI.pgget('bfile', fields, 'bid = {}'.format(bid), logact)
+   brec = BFILES[bid]
+   if not brec: return 0
+
+   if 'sfile' in frec:
+      fname = frec['sfile']
+      ftype = 'Saved'
+   else:
+      fname = frec['wfile']
+      ftype = 'Web'
+   ret = 1
+   fdate = frec['date_modified']
+   bdate = brec['date_modified']
+   if chgdays > 0 and PgUtil.diffdate(fdate, bdate) >= chgdays:
+      ret = -1
+      if brec['note']:
+         mp = r'{}<:>{}<:>(\d+)<:>(\w+)<:>'.format(fname, frec['type']) 
+         ms = re.search(mp, brec['note'])
+         if ms:
+            fsize = int(ms.group(1))
+            cksum = ms.group(2)
+            if cksum and cksum == frec['checksum'] or not cksum and fsize == frec['data_size']:
+               ret = 1
+
+   if logact:
+      if ret == 1:
+         msg = "{}-{}: {} file backed up to /{}/{} by {}".format(frec['dsid'], fname, ftype, brec['dsid'], brec['bfile'], bdate)
+      else:
+         msg = "{}-{}: {} file changed on {}".format(frec['dsid'], fname, ftype, fdate)
+      PgLOG.pglog(msg, logact)
+
+   return ret
