@@ -402,15 +402,11 @@ def pglog(msg, logact = MSGLOG):
       if logact&EMLLOG: logact &= ~EMLLOG
       if not logact&ERRLOG: logact &= ~EMEROL
 
-   if msg: msg = msg.lstrip()  # remove leading whitespaces for logging message
-
+   msg = msg.lstrip() if msg else ''  # remove leading whitespaces for logging message
    if logact&EXITLG:
       ext = "Exit 1 in {}\n".format(os.getcwd())
-      if not msg:
-         msg = ext
-      else:
-         msg = msg.rstrip()
-         msg += "; " + ext
+      if msg: msg = msg.rstrip() + "; "
+      msg += ext
    else:
       if msg and not re.search(r'(\n|\r)$', msg): msg += "\n"
       if logact&RETMSG: retmsg = msg
@@ -418,7 +414,8 @@ def pglog(msg, logact = MSGLOG):
    if logact&EMLALL:
       if logact&SNDEML or not msg:
          title = (msg if msg else "Message from {}-{}".format(PGLOG['HOSTNAME'], get_command()))
-         msg = send_email(title.rstrip())
+         msg = title + '\n' + msg
+         send_email(title.rstrip())
       elif msg:
          set_email(msg, logact)
 
@@ -428,7 +425,8 @@ def pglog(msg, logact = MSGLOG):
       if not logact&EMLALL: set_email(msg, logact)
       title = "ABORTS {}-{}".format(PGLOG['HOSTNAME'], get_command())
       set_email((("ABORTS " + CPID['PID']) if CPID['PID'] else title), EMLTOP)
-      msg += send_email(title)
+      msg = title + '\n' + msg
+      send_email(title)
 
    if logact&LOGERR: # make sure error is always logged
       msg = break_long_string(msg)
@@ -1315,11 +1313,11 @@ def set_common_pglog():
    SETPGLOG("DBGLEVEL", '')                             # debug level
    SETPGLOG("DBGPATH", PGLOG['DSSDBHM']+"/log")         # path to debug log file
    SETPGLOG("OBJCTBKT", "rda-data")                     # default Bucket on Object Store
-   SETPGLOG("BACKUPEP", "rda-quasar")                   # default Globus Endpoint on Quasar
-   SETPGLOG("DRDATAEP", "rda-quasar-drdata")            # DRDATA Globus Endpoint on Quasar
+   SETPGLOG("BACKUPEP", "gdex-quasar")                   # default Globus Endpoint on Quasar
+   SETPGLOG("DRDATAEP", "gdex-quasar-drdata")            # DRDATA Globus Endpoint on Quasar
    SETPGLOG("DBGFILE", "pgdss.dbg")                     # debug file name
    SETPGLOG("CNFPATH", PGLOG['DSSHOME']+"/config")      # path to configuration files
-   SETPGLOG("DSSURL",  "https://rda.ucar.edu")          # current dss web URL
+   SETPGLOG("DSSURL",  "https://gdex.ucar.edu")          # current dss web URL
    SETPGLOG("RQSTURL", "/datasets/request")              # request URL path
    SETPGLOG("WEBSERVERS", "rda-web-prod01.ucar.edu:rda-web-test01.ucar.edu")                 # webserver names for Web server
    PGLOG['WEBHOSTS'] = PGLOG['WEBSERVERS'].split(':') if PGLOG['WEBSERVERS'] else []
@@ -1330,7 +1328,7 @@ def set_common_pglog():
    SETPGLOG("DSSWEB",  PGLOG['LOCDATA']+"/web")
    SETPGLOG("DSWHOME", PGLOG['DSSWEB']+"/datasets")     # datast web root path
    PGLOG['HOMEROOTS'] = "{}|{}".format(PGLOG['DSSHOME'], PGLOG['DSWHOME'])
-   SETPGLOG("DSSDATA", "/glade/campaign/collections/rda")                     # dss data root path
+   SETPGLOG("DSSDATA", "/glade/campaign/collections/gdex")                     # dss data root path
    SETPGLOG("DSDHOME", PGLOG['DSSDATA']+"/data")        # dataset data root path
    SETPGLOG("DECSHOME", PGLOG['DSSDATA']+"/decsdata")   # dataset decsdata root path
    SETPGLOG("DSHHOME", PGLOG['DECSHOME']+"/helpfiles")  # dataset help root path
@@ -1354,12 +1352,12 @@ def set_common_pglog():
    os.environ['history'] = '0'
 
    # set tmp dir
-   SETPGLOG("TMPPATH", "/glade/campaign/collections/rda/work/ptmp")
+   SETPGLOG("TMPPATH", "/glade/campaign/collections/gdex/work/ptmp")
    if not PGLOG['TMPPATH']: PGLOG['TMPPATH'] = "/data/ptmp"
 
    SETPGLOG("TMPDIR", '')
    if not PGLOG['TMPDIR']:
-      PGLOG['TMPDIR'] = "/glade/campaign/collections/rda/scratch/" + PGLOG['CURUID']
+      PGLOG['TMPDIR'] = "/glade/campaign/collections/gdex/scratch/" + PGLOG['CURUID']
       os.environ['TMPDIR'] = PGLOG['TMPDIR']
 
    # empty diretory for HOST-sync
